/*
  Run this program and then resize the window so that is no longer
  a square window. Notice how the image is distorted into an ellipse.

  When you resize the window, the aspect ratio of the scene in world
  coordinates (that is, the aspect ration of the "world screen") no
  longer matches the aspect ration of the viewport. The "world screen"
  gets distorted so that it fits into the viewport.

  We can fix this by registering a GLUT "reshape event handler" that
  calls the glViewport() function.
*/
#include <windows.h>
#include <math.h>
#include "glut.h"
//#include <GLUT/glut.h>
//#include <GL/glut.h>


/* Prototype for the display() callback function */
void display(void);
void reshape(int, int);

int main(int argc, char** argv)
{
   /* Standard GLUT initialization */
   glutInit(&argc,argv);
   glutInitDisplayMode (GLUT_SINGLE | GLUT_RGB); /* default, not needed */
   glutInitWindowSize(500,500);      /* 500 x 500 pixel window */
   glutInitWindowPosition(50,50);    /* place window near top left of display */
   glutCreateWindow("Circle");       /* window title */
   glutDisplayFunc(display);         /* display callback invoked when window is redrawn */
   glutReshapeFunc(reshape);         /* reshape callback invoked when window is resized */

   /* Initialize OpenGL state */
   /* attributes */
   glShadeModel(GL_FLAT);            /* default is GL_SMOOTH */
   glFrontFace(GL_CCW);
   glPolygonMode(GL_FRONT, GL_LINE);
   glPolygonMode(GL_BACK, GL_FILL);
   glClearColor(1.0, 1.0, 1.0, 1.0); /* white background */
   glColor3f(1.0, 0.0, 0.0);         /* draw in red */
   /* set up viewing */
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(-2.0, 2.0, -2.0, 2.0); /* viewing volume */
   glMatrixMode(GL_MODELVIEW);

   /* Enter event loop */
   glutMainLoop();

   return 0;  /* we never get here */
}//main()


/* The display() callback function */
void display( void )
{
   const double PI = 3.14159265;
   int numPoints = 100;
   int n;

   glClear(GL_COLOR_BUFFER_BIT);  /* clear the window */

   glBegin(GL_TRIANGLE_FAN);
     glVertex2f(0.0, 0.0);
     for (n = 0; n <= numPoints; n++)
        glVertex2f(cos((n/(double)numPoints)*2*PI), sin((n/(double)numPoints)*2*PI));
   glEnd();

   glFlush(); /* clear buffers */
}//display()


/* The reshape() callback function */
void reshape(int width, int height)
{
   // specify the viewport (viewport is always the whole window)
   glViewport(0, 0, width, height);

   //display();  // Try uncommenting this line. What effect does it have?

   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
}//reshape()