/*
  This program uses a GLUT "reshape event handler" and the
  glViewport() function to solve the problem of changing
  aspect ratios demonstrated by the program circle.c

  This program always draws a square viewport, that is as
  large as possible, and is in the lower left hand corner
  of this program's window.

  As an exercise, modify this program to always place the
  square viewport in the upper left hand corner of the window.

  Also try placing the square viewport centered on the left
  edge of the window.

  Finally, try placing the square viewport at the center
  of the window.
*/
#include <windows.h>
#include <stdio.h>
#include <math.h>
#include "glut.h"
//#include <GLUT/glut.h>
//#include <GL/glut.h>


/* Prototypes for the display() and reshape() callback functions */
void display(void);
void reshape(int, int);

int viewportSize;  // this is set by the reshape() callback function


int main(int argc, char** argv)
{
   /* Standard GLUT initialization */
   glutInit(&argc,argv);
   glutInitDisplayMode (GLUT_SINGLE | GLUT_RGB); /* default, not needed */
   glutInitWindowSize(500,500);      /* 500 x 500 pixel window */
   glutInitWindowPosition(50,50);    /* place window near top left of display */
   glutCreateWindow("Circle v2");    /* window title */
   glutDisplayFunc(display);         /* display callback invoked when window is redrawn */
   glutReshapeFunc(reshape);         /* reshape callback invoked when window is resized */

   /* Initialize OpenGL state */
   /* attributes */
   glShadeModel(GL_FLAT);            /* default is GL_SMOOTH */
   glFrontFace(GL_CCW);
   glPolygonMode(GL_FRONT, GL_LINE);
   glPolygonMode(GL_BACK, GL_FILL);
   glClearColor(1.0, 1.0, 1.0, 1.0); /* white background */
   glColor3f(1.0, 0.0, 0.0);         /* draw in red */
   /* set up viewing */
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(-2.0, 2.0, -2.0, 2.0); /* viewing volume */
   glMatrixMode(GL_MODELVIEW);

   /* Enter event loop */
   glutMainLoop();

   return 0;  /* we never get here */
}//main()


/* The display() callback function */
void display( void )
{
   const double PI = 3.14159265;
   int numPoints = 100;
   int n;

   glClear(GL_COLOR_BUFFER_BIT);  /* clear the window */

   glBegin(GL_TRIANGLE_FAN);
     glVertex2f(0.0, 0.0);
     for (n = 0; n <= numPoints; n++)
        glVertex2f(cos((n/(double)numPoints)*2*PI), sin((n/(double)numPoints)*2*PI));
   glEnd();

   glFlush(); /* clear buffers */

   printf("We got a \"display()\" event\n");
}//display()


/* The reshape() callback function */
void reshape(int width, int height)
{
   // set the viewport size to be the minimum of width and height
   if (width <= height)
      viewportSize = width;
   else
      viewportSize = height;

   // specify the viewport
   glViewport(0, 0, viewportSize, viewportSize);

   display();  // Try commenting this line. What effect does it have?

   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
}//reshape()
