/*
   This is a corrected and slightly reorganized version of Figure 3.3 from pages 93-94.

   This version makes the viewport the whole program window, so the aspect ratio of the
   graph is not preserved and the shape of the graph is distorted.
*/
#include <windows.h>
#include <math.h>
#include "glut.h"

#include "plot-sinc.h"  // defines some global constants

void reshape(int, int);

int windowHeight;    // this is set by the reshape() callback function
int windowWidth;     // this is set by the reshape() callback function

void myDisplay(void) // plot the sinc function, using world coordinates
{
   const float pi = 3.14159265358979;
   GLfloat x;

   // specify the viewport
   glViewport( 0,  0, windowWidth, windowHeight); // left, bottom, width, height (in pixels)

   glClear( GL_COLOR_BUFFER_BIT );

   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   glBegin(GL_LINE_STRIP);
      for(x = graphLeft; x < graphRight; x += 0.01)  // draw the plot
      {
         glVertex2f(x, sin(pi * x) / (pi * x));
      }
   glEnd();
   glFlush();
}


int main(int argc, char** argv)
{
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
   // specify the screen window
   glutInitWindowSize(640,480);       // width, height (in pixels)
   glutInitWindowPosition(100,150);   // left, top (in pixels)
   glutCreateWindow("Sinc Function");
   glutDisplayFunc(myDisplay);
   glutReshapeFunc(reshape);

   glClearColor(1.0,1.0,1.0,0.0);
   glColor3f(0.0f,0.0f,1.0f);
   glLineWidth(1.0);

   // specify the world window
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(graphLeft, graphRight, graphBottom, graphTop); // in world coordinates

   glutMainLoop( );

   return 0;
}

/* The reshape() callback function */
void reshape(int width, int height)
{
   windowWidth  = width;
   windowHeight = height;

   myDisplay();  // Try commenting this line. What effect does it have?

   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
}//reshape()