/*
   This is a corrected and slightly reorganized version of Figure 3.3 from pages 93-94.

   This version adjusts the viewport and the world window so that the aspect ratio of the
   graph is preserved (and the shape of the graph is not distorted) and also so that the
   entire height of the program window is always used. This means that when the program
   window is too narrow, part of the left and right ends of the graph must be cut off.
   Notice that "cutting off" the left and right ends of the graph is done by adjusting the
   world window.
*/
#include <windows.h>
#include <math.h>
#include "glut.h"

#include "plot-sinc.h"  // defines some global constants

void reshape(int, int);

int windowHeight;    // this is set by the reshape() callback function
int windowWidth;     // this is set by the reshape() callback function

void myDisplay(void) // plot the sinc function, using world coordinates
{
   int viewportLeft, viewportBottom, viewportWidth, viewportHeight;
   double worldLeftEdge, worldRightEdge;
   const float pi = 3.14159265358979;
   GLfloat x;

   // specify the viewport
   if ( (double)windowWidth/(double)windowHeight >= aspectRatio )
   {
      viewportWidth = (int)(windowHeight*aspectRatio);
      viewportLeft = (windowWidth-viewportWidth)/2;
   }
   else
   {
      viewportWidth = windowWidth;
      viewportLeft  = 0;
   }
   viewportHeight = windowHeight;  // always use the entire height of the program window
   viewportBottom = 0;
   glViewport(viewportLeft, viewportBottom, viewportWidth, viewportHeight);

   // specify the world window
   if ( (double)windowWidth/(double)windowHeight >= aspectRatio )
   {
      worldLeftEdge = graphLeft;
   }
   else
   {
      if (viewportHeight != 0)  // check for minimized program window
      {
         worldLeftEdge =  -(((double)viewportWidth/(double)viewportHeight)*graphHeight)/2.0;
      }
      else
      {
         worldLeftEdge = 0;
      }
   }
   printf("worldLeftEdge = %f, viewportHeight = %d\n", worldLeftEdge, viewportHeight);

   worldRightEdge = - worldLeftEdge;

   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(worldLeftEdge, worldRightEdge, graphBottom, graphTop);

   glClear( GL_COLOR_BUFFER_BIT );

   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();

   glBegin(GL_LINE_STRIP);
      for(x = worldLeftEdge; x < worldRightEdge; x += 0.01)  // draw the plot
      {
         glVertex2f(x, sin(pi * x) / (pi * x));
      }
   glEnd();
   glFlush();
}


int main(int argc, char** argv)
{
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
   // specify the screen window
   glutInitWindowSize(640,480);       // width, height (in pixels)
   glutInitWindowPosition(100,150);   // left, top (in pixels)
   glutCreateWindow("Sinc Function");
   glutDisplayFunc(myDisplay);
   glutReshapeFunc(reshape);

   glClearColor(1.0,1.0,1.0,0.0);
   glColor3f(0.0f,0.0f,1.0f);
   glLineWidth(1.0);

   glutMainLoop( );

   return 0;
}


/* The reshape() callback function */
void reshape(int width, int height)
{
   windowWidth  = width;
   windowHeight = height;

   myDisplay();  // Try commenting this line. What effect does it have?

   printf("We got a \"reshape(%d, %d)\" event\n", width, height);
}//reshape()